@@ -25,12 +25,13 @@
 Auxiliary Data Processing
 """
 
+from __future__ import unicode_literals
+
 import os.path
 import re
 import logging
 import csv
 
-import edbob
 from edbob.util import requires_impl
 
 from rattail.core import Object
@@ -41,7 +42,7 @@ from rattail.util import load_object
 from rattail.files import overwriting_move
 
 
-auxiliary_pattern = re.compile(r'^(\d{8})_(.+)_LOAD.CSV$', re.IGNORECASE)
+auxiliary_pattern = re.compile(r'^(?P<batch_id>\d{8})_(?P<batch_type>.+)_LOAD.CSV$', re.IGNORECASE)
 
 log = logging.getLogger(__name__)
 
@@ -105,7 +106,7 @@ class DataLoader(Object):
         valid_keys = []
 
         csv_file = open(csv_path, 'rb')
-        reader = csv.DictReader(csv_file, quotechar="'")
+        reader = csv.DictReader(csv_file, quotechar=b"'")
         for row in reader:
             key = self.load_instance(row)
             valid_keys.append(key)
@@ -258,48 +259,36 @@ class CustomerGroupLoader(DataLoader):
         self.session.delete(group)
 
 
-def process_auxiliary(path):
+def process_auxiliary(path, processor_factory=None):
     """
-    Processes auxiliary data which has been deployed from an SMS server
-    instance.
+    Processes auxiliary CSV data which has been deployed from an SMS server
+    instance, which has the Deploy_Rattail option installed.
 
-    .. highlight:: ini
-    
-    This function is designed to be called by a file monitor instance.  An
-    example of such configuration would be::
+    This action is designed to be called by the file monitor.  An example
+    configuration would be (note that some things are optional):
 
-       [edbob.filemon]
-       monitored = sms_auxiliary
-       sms_auxiliary.dirs = [r'C:\Storeman\XchRattail\Auxiliary']
-       sms_auxiliary.actions = ['rattail_locsms.auxiliary:process_auxiliary', 'os:remove']
+    .. code-block:: ini
 
-    If you wish to override the default data processor class, then you should
-    additionally provide configuration similar to this::
-
-       [rattail.sw.locsms]
-       auxiliary.processor_class = myrattail.mymodule:MyAuxiliaryProcessor
+       [rattail.filemon]
+       monitor = sms_auxiliary
+       sms_auxiliary.dirs = C:\Storeman\XchRattail\Auxiliary
+       sms_auxiliary.actions = process, delete
+       sms_auxiliary.action.process.func = rattail_locsms.auxiliary:process_auxiliary
+       sms_auxiliary.action.process.kwarg.processor_factory = mymodule:MyAuxiliaryProcessor
+       sms_auxiliary.action.delete.func = os:remove
     """
-
-    m = auxiliary_pattern.match(os.path.basename(path))
-    if not m:
-        log.warning("process_auxiliary: Unexpected filename pattern: %s" % path)
+    match = auxiliary_pattern.match(os.path.basename(path))
+    if not match:
+        log.warning("unexpected filename pattern: {0}".format(repr(path)))
         return
 
-    batch_type = m.group(2).upper()
+    batch_type = match.group('batch_type').upper()
 
-    cls = edbob.config.get('rattail.sw.locsms', 'auxiliary.processor_class')
-    if cls:
-        log.debug("using custom auxiliary processor class: {0}".format(cls))
-        cls = load_object(cls)
+    if processor_factory is not None:
+        log.debug("using custom auxiliary processor factory: {0}".format(repr(processor_factory)))
+        processor_factory = load_object(processor_factory)
     else:
-        cls = AuxiliaryProcessor
-    proc = cls()
+        processor_factory = AuxiliaryProcessor
 
-    # Process CSV file; details are up to the class instance.
-    proc.process_load(batch_type, path)
-
-    # Move data file to 'Processed' folder.
-    processed_dir = os.path.join(os.path.dirname(path), 'Processed')
-    if not os.path.exists(processed_dir):
-        os.makedirs(processed_dir)
-    overwriting_move(path, processed_dir)
+    processor = processor_factory()
+    processor.process_load(batch_type, path)
