@@ -26,6 +26,8 @@
 Processing Deployed Changes
 """
 
+from __future__ import unicode_literals
+
 import os
 import os.path
 import re
@@ -49,8 +51,8 @@ from rattail.util import load_object
 from rattail.files import overwriting_move
 
 
-change_pattern_generic = re.compile(r'^(\d{8})_(.+)$')
-change_pattern = re.compile(r'^\d{8}_(.+)\.csv$', re.IGNORECASE)
+change_pattern_generic = re.compile(r'^(?P<batch_id>\d{8})_(?P<batch_name>.+)$')
+change_pattern = re.compile(r'^\d{8}_(?P<batch_name>.+)\.csv$', re.IGNORECASE)
 
 log = logging.getLogger(__name__)
 
@@ -74,7 +76,7 @@ class ChangesProcessor(Object):
                 log.debug("processing change file: {0}".format(repr(csv_path)))
 
                 csv_file = open(csv_path, 'rb')
-                reader = csv.DictReader(csv_file, quotechar="'")
+                reader = csv.DictReader(csv_file, quotechar=b"'")
                 for row in reader:
                     func(row, session)
                     session.flush()
@@ -879,64 +881,68 @@ class ChangesProcessor(Object):
         session.delete(employee)
 
 
-def process_changes(path):
+def process_changes(path, backup_dir='processed', processor_factory=None):
     """
-    Processes "changes" data which has been deployed from an SMS server
-    instance.
+    Processes "changes" CSV data which has been deployed from an SMS server
+    instance, with the Deploy_Rattail option installed.
 
-    .. highlight:: ini
-    
-    This function is designed to be called by a file monitor instance.  An
-    example of such configuration would be::
+    This function is designed to be called by the file monitor.  An example
+    configuration would be (note that some things are optional):
 
-       [edbob.filemon]
-       monitored = sms_changes
-       sms_changes.dirs = [r'C:\Storeman\XchRattail\Changes']
-       sms_changes.actions = ['rattail_locsms.changes:process_changes']
+    .. code-block:: ini
+
+       [rattail.filemon]
+       monitor = sms_changes
+       sms_changes.dirs = C:\Storeman\XchRattail\Changes
+       sms_changes.actions = process
+       sms_changes.action.process.func = rattail_locsms.changes:process_changes
+       sms_changes.action.process.kwarg.backup_dir = /my/changes/backup/dir
+       sms_changes.action.process.kwarg.processor_factory = mymodule:MyChangesProcessor
 
     If you wish to override the default data processor class, then you should
-    additionally provide configuration similar to this::
+    additionally provide configuration similar to this:
+
+    .. code-block:: ini
 
        [rattail.sw.locsms]
        changes.processor_class = myrattail.mymodule:MyChangesProcessor
     """
-
-    m = change_pattern_generic.match(os.path.basename(path))
-    if not m:
+    match = change_pattern_generic.match(os.path.basename(path))
+    if not match:
         log.warning("unexpected filename pattern: {0}".format(repr(path)))
         return
 
     # Ignore all incoming files until we see one indicating "batch" completion.
-    if m.group(2).upper() != 'CHANGES_END':
+    if match.group('batch_name').upper() != 'CHANGES_END':
         return
 
-    deploy_id = m.group(1)
+    deploy_id = match.group('batch_id')
 
     changes = {}
     changes_dir = os.path.dirname(path)
     for fn in os.listdir(changes_dir):
         if fn.startswith(deploy_id):
-            m = change_pattern.match(fn)
-            if m:
-                changes[m.group(1).upper()] = os.path.join(changes_dir, fn)
+            match = change_pattern.match(fn)
+            if match:
+                changes[match.group('batch_name').upper()] = os.path.join(changes_dir, fn)
 
-    cls = edbob.config.get('rattail.sw.locsms', 'changes.processor_class')
-    if cls:
-        log.debug("using custom changes processor class: {0}".format(cls))
-        cls = load_object(cls)
+    if processor_factory is not None:
+        log.debug("using custom changes processor factory: {0}".format(processor_factory))
+        processor_factory = load_object(processor_factory)
     else:
-        cls = ChangesProcessor
-    proc = cls()
+        processor_factory = ChangesProcessor
 
-    # Process all changes; details of this are up to the class instance.
-    proc.process_all_changes(changes)
+    processor = processor_factory()
+    processor.process_all_changes(changes)
 
-    # Create 'Processed' folder if it doesn't already exist.
-    processed_dir = os.path.join(changes_dir, 'Processed')
-    if not os.path.exists(processed_dir):
-        os.makedirs(processed_dir)
+    if os.path.basename(backup_dir) == backup_dir:
+        backup_dir = os.path.join(changes_dir, backup_dir)
+    else:
+        backup_dir = os.path.abspath(backup_dir)
 
-    # Move all files from change "batch" to 'Processed' folder.
+    log.debug("backing up data files in dir: {0}".format(backup_dir))
+    if not os.path.exists(backup_dir):
+        os.makedirs(backup_dir)
     for fn in list(os.listdir(changes_dir)):
         if fn.startswith(deploy_id):
-            overwriting_move(os.path.join(changes_dir, fn), processed_dir)
+            overwriting_move(os.path.join(changes_dir, fn), backup_dir)
