@@ -1,9 +1,8 @@
-#!/usr/bin/env python
-# -*- coding: utf-8  -*-
+# -*- coding: utf-8 -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2012 Lance Edgar
+#  Copyright © 2010-2014 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -26,6 +25,8 @@
 SMS Data Loader
 """
 
+from __future__ import unicode_literals
+
 import datetime
 import logging
 
@@ -38,7 +39,6 @@ import edbob
 from edbob.time import localize
 from edbob.util import requires_impl
 
-from rattail.core import Object
 from rattail.gpc import GPC
 from rattail.db import Session
 from rattail.db import model
@@ -56,8 +56,8 @@ class DataAlreadyLoadedError(Exception):
         return "SMS data has already been loaded"
 
 
-def restrict_by(name, query, column):
-    values = edbob.config.get('rattail.sw.locsms', 'load.restrictions.%s' % name)
+def restrict_by(config, name, query, column):
+    values = config.get('rattail.sw.locsms', 'load.restrictions.%s' % name)
     if values:
         values = values.split(',')
         values = [x.strip() for x in values]
@@ -65,11 +65,14 @@ def restrict_by(name, query, column):
     return query
 
 
-class LoadProcessor(Object):
+class LoadProcessor(object):
     """
     Generic class for performing a full data load from SMS.
     """
 
+    def __init__(self, config):
+        self.config = config
+
     def load_all_data(self, progress=None):
         """
         Loads all relevant data from SMS into Rattail.
@@ -84,7 +87,7 @@ class LoadProcessor(Object):
 
         cancel = False
         for loader in self.relevant_loaders():
-            loader = loader(session=session, sms_session=sms_session)
+            loader = loader(self.config, session, sms_session)
             if not loader.perform_load(progress):
                 cancel = True
                 break
@@ -98,7 +101,6 @@ class LoadProcessor(Object):
         session.close()
         sms_session.close()
 
-
     def relevant_loaders(self):
         """
         Generator which should yield all relevant data loader classes.
@@ -117,11 +119,16 @@ class LoadProcessor(Object):
         yield OperatorLoader
 
 
-class DataLoader(Object):
+class DataLoader(object):
     """
     Generic class for performing a particular type of data load from SMS.
     """
 
+    def __init__(self, config, session, sms_session):
+        self.config = config
+        self.session = session
+        self.sms_session = sms_session
+
     @property
     @requires_impl(is_property=True)
     def sms_class(self):
@@ -291,7 +298,7 @@ class ProductLoader(DataLoader):
 
     def get_sms_query(self):
         q = super(ProductLoader, self).get_sms_query()
-        q = restrict_by('F01', q, locsms.Product.F01)
+        q = restrict_by(self.config, 'F01', q, locsms.Product.F01)
         return q
 
     def get_sms_iterable(self, sms_query):
@@ -364,7 +371,7 @@ class CostLoader(DataLoader):
 
     def get_sms_query(self):
         q = super(CostLoader, self).get_sms_query()
-        q = restrict_by('F01', q, locsms.Cost.F01)
+        q = restrict_by(self.config, 'F01', q, locsms.Cost.F01)
         return q
 
     def get_sms_iterable(self, sms_query):
@@ -422,7 +429,7 @@ class PriceLoader(DataLoader):
 
     def get_sms_query(self):
         q = super(PriceLoader, self).get_sms_query()
-        q = restrict_by('F01', q, locsms.Price.F01)
+        q = restrict_by(self.config, 'F01', q, locsms.Price.F01)
         return q
 
     def utc_timestamp(self, date, time):
@@ -552,7 +559,7 @@ class CustomerLoader(DataLoader):
 
     def get_sms_query(self):
         q = super(CustomerLoader, self).get_sms_query()
-        q = restrict_by('F1148', q, locsms.Customer.F1148)
+        q = restrict_by(self.config, 'F1148', q, locsms.Customer.F1148)
         return q
 
     def load_sms_instance(self, sms_customer):
